pitchtools.IntervalObjectSet
============================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet

.. autoclass:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.union
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__cmp__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__rand__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__ror__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__rsub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__rxor__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__xor__
   :noindex:
